import pytest
from psycopg.errors import UniqueViolation

from src.neo_neo_todo.models.member import (
    insert_member,
    select_member_by_email,
    select_member_by_id,
)


async def test_model_member_select_by_email(db_pool):
    member = await select_member_by_email(db_pool, "member@todo.test")
    assert member is not None
    assert member.email == "member@todo.test"


async def test_model_member_select_by_id(db_pool):
    member = await select_member_by_id(db_pool, 1)
    assert member is not None
    assert member.id == 1


async def test_model_member_insert(db_pool):
    member = await insert_member(
        db_pool, "member_inserted@todo.test", "alkasdjfhasldkfjh12341238989"
    )
    assert member is not None
    assert member.id == 2
    assert member.email == "member_inserted@todo.test"
    assert member.password_hash == "alkasdjfhasldkfjh12341238989"

    with pytest.raises(UniqueViolation):
        await insert_member(
            db_pool, "Member_inserted@todo.test", "alkasdjfhasldkfjh12341238989"
        )
